@@ -37,7 +37,7 @@ has entry_datas => (
                 guid        => $_->tag_uri->as_string,
                 published   => XML::FeedPP::Util::epoch_to_w3cdtf($_->published_at->epoch),
                 link        => $_->url,
-            } } @{ $self->blog->entries(sort_by => 'last_modified_at', limit => 20) }
+            } } @{ $self->blog->entries(sort_by => 'last_modified_at') }
         ]
     },
 );
